#ifndef SCI_DEF_COL
#define SCI_DEF_COL
/*------------------------------------------------------------------------
 *    Graphic library
 *    Copyright (C) 1998-2000 Enpc/Jean-Philippe Chancelier
 *    jpc@cereve.enpc.fr 
 --------------------------------------------------------------------------*/
#define GREYNUMBER 17
#define DEFAULTNUMCOLORS 32
extern unsigned short default_colors[];
#define DEFAULTBLACK 0
#define DEFAULTWHITE 7

#endif 
